@@ -1,7 +1,3 @@
-"""
-The main api class which will be used to authenticate and connect to the spotify api
-"""
-
 # ##################################################################################################
 #  Copyright (c) 2020. HuiiBuh                                                                     #
 #  This file (spotify_api_client.py) is part of AsyncSpotify which is released under MIT.          #
@@ -15,7 +11,7 @@ import time
 import webbrowser
 from copy import deepcopy
 from types import SimpleNamespace
-from typing import Optional, List
+from typing import Optional, List, Union
 from urllib import parse
 from urllib.parse import urlencode
 
@@ -37,8 +33,10 @@ from ._endpoints.tracks import Track
 from ._endpoints.urls import URLS
 from ._endpoints.user import User
 from ._response_status import ResponseStatus
-from .spotify_api_preferences import SpotifyApiPreferences
 from .._error_message import ErrorMessage
+from ..authentification.authorization_flows import AuthorizationCodeFlow
+from ..authentification.authorization_flows.authorization_flow import AuthorizationFlow
+from ..authentification.authorization_flows.client_credentials_flow import ClientCredentialsFlow
 from ..authentification.spotify_authorization_token import SpotifyAuthorisationToken
 from ..authentification.spotify_cookies import SpotifyCookie
 from ..spotify_errors import SpotifyError
@@ -47,11 +45,10 @@ from ..token_renew_class import TokenRenewClass
 
 class SpotifyApiClient:
     """
-    The main api class which will be used to authenticate and connect to the spotify api.
-    Use this class to authenticate and connect to the spotify api.
+    The class which will be used to authenticate and connect to the spotify api.
     """
 
-    def __init__(self, preferences: SpotifyApiPreferences,
+    def __init__(self, authorization_flow: AuthorizationFlow,
                  hold_authentication=False,
                  spotify_authorisation_token: SpotifyAuthorisationToken = None,
                  token_renew_instance: TokenRenewClass = None):
@@ -59,15 +56,15 @@ class SpotifyApiClient:
         Create a new api class
 
         Args:
-            preferences: The preferences object fully filled with information
+            authorization_flow: The auth_code_flow object fully filled with information
             hold_authentication: Should the api keep the authentication im memory and refresh it automatically
             token_renew_instance: An instance of a class which handles the renewing of the token if it should expire
         """
 
-        # Check if the preferences are valid
-        if not preferences.valid:
-            raise SpotifyError(ErrorMessage(message="The preferences of your app are not correct").__dict__)
-        self.preferences: SpotifyApiPreferences = preferences
+        # Check if the auth_code_flow are valid
+        if not authorization_flow.valid:
+            raise SpotifyError(ErrorMessage(message="The auth flow instance of your app is not correct").__dict__)
+        self.authorization_flow: AuthorizationFlow = authorization_flow
 
         # Set the SpotifyAuthorisationToken
         if spotify_authorisation_token:
@@ -167,12 +164,16 @@ class SpotifyApiClient:
             The encoded url which can be used to authorize a new or existing user
         """
 
+        self._enforce_flows()
+
+        # TODO PKCEFlow
+        self.authorization_flow: Union[AuthorizationCodeFlow]
         params = {
-            "client_id": self.preferences.application_id,
+            "client_id": self.authorization_flow.application_id,
             "response_type": "code",
-            "scope": ' '.join(self.preferences.scopes),
+            "scope": ' '.join(self.authorization_flow.scopes),
             "show_dialog": f"{show_dialog}",
-            "redirect_uri": f"{self.preferences.redirect_url}"
+            "redirect_uri": f"{self.authorization_flow.redirect_url}"
         }
 
         # Check if a state is required
@@ -312,6 +313,11 @@ class SpotifyApiClient:
             A valid SpotifyAuthorisationToken
         """
 
+        if not isinstance(self.authorization_flow, ClientCredentialsFlow):
+            raise SpotifyError(ErrorMessage(
+                message="Your authorization flow cannot build an authorization url. "
+                        "Select the ClientCredentialsFlow instead").__dict__)
+
         body: dict = {
             'grant_type': 'client_credentials',
         }
@@ -335,10 +341,14 @@ class SpotifyApiClient:
             A valid SpotifyAuthorisationToken
         """
 
+        # TODO PKCEFlow
+        self._enforce_flows()
+        self.authorization_flow: Union[AuthorizationCodeFlow]
+
         body: dict = {
             'grant_type': 'authorization_code',
             'code': code,
-            'redirect_uri': self.preferences.redirect_url
+            'redirect_uri': self.authorization_flow.redirect_url
         }
 
         return await self._get_token(body)
@@ -379,6 +389,8 @@ class SpotifyApiClient:
             The SpotifyAuthorisationToken
         """
 
+        self._enforce_flows()
+
         # Check if the internal auth token should be used
         if not auth_token and self._hold_authentication:
             auth_token = self._spotify_authorisation_token
@@ -411,9 +423,11 @@ class SpotifyApiClient:
             The access token and the refresh token if the grant_type was code
         """
 
+        self.authorization_flow: Union[ClientCredentialsFlow, AuthorizationCodeFlow]
+
         # Build the header of the request
         base_64: base64 = base64.b64encode(
-            f'{self.preferences.application_id}:{self.preferences.application_secret}'.encode('ascii'))
+            f'{self.authorization_flow.application_id}:{self.authorization_flow.application_secret}'.encode('ascii'))
         header: dict = {'Authorization': f'Basic {base_64.decode("ascii")}'}
 
         # Make the request to the api
@@ -457,6 +471,16 @@ class SpotifyApiClient:
 
         return await self._api_request_handler.make_request('GET', url, {}, auth_token)
 
+    def _enforce_flows(self):
+        """
+        Make sure that the flows are ether the AuthorizationCodeFlow or the PKCEFlow
+        """
+        # TODO PKCEFlow
+        if not isinstance(self.authorization_flow, AuthorizationCodeFlow):
+            raise SpotifyError(ErrorMessage(
+                message="Your authorization flow cannot build an authorization url. "
+                        "Select the AuthorizationCodeFlow or the PKCEFlow instead").__dict__)
+
     @property
     def spotify_authorization_token(self) -> SpotifyAuthorisationToken:
         """
